@@ -202,11 +202,7 @@ int mqtt3_socket_listen(const char *host, uint16_t port, int **socks, int *sock_
 
 		sock = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);
 		if(sock == -1){
-			mqtt3_log_printf(MOSQ_LOG_ERR, "Error: %s", strerror(errno));
-			//UV: The Maemo stock kernel does not support ipv6. Returning out of this loop
-			// will abort all communication. Don't do this.
-			//return 1;
-			// Instead, just ignore this failed interface and get to the next one.
+			mqtt3_log_printf(MOSQ_LOG_WARNING, "Warning: %s", strerror(errno));
 			continue;
 		}
 		(*sock_count)++;
@@ -259,7 +255,12 @@ int mqtt3_socket_listen(const char *host, uint16_t port, int **socks, int *sock_
 	}
 	freeaddrinfo(ainfo);
 
-	return 0;
+    // We need to have at least one working socket
+	if(*sock_count > 0){
+		return 0;
+	}else{
+		return 1;
+	}
 }
 
 int mqtt3_net_packet_queue(mqtt3_context *context, struct _mosquitto_packet *packet)
